pub enum CapsuleError {
Show 22 variants
Generic(String),
DEKNotFound(String),
DEKUnexpectedType(String),
DEKWrongLength(String),
CBOREncodeFailed(String),
CBORDecodeFailed(String),
EncryptionFailure(String),
DecryptionFailure(String),
BadMagic(String),
UnsupportedVersion(String),
CapsuleAlreadySealed(String),
StreamWriteFailure(String),
StreamReadFailure(String),
FileIOError(String),
InsufficientPermissions(String),
DRDecryptError(String),
CapsuleOpenError(String),
CapsuleUpdateError(String),
EndOfRow,
EndOfCapsule,
CapsuleAccessDeniedByPolicy,
RowAccessDeniedByPolicy,
}Expand description
CapsuleError contains the possible errors that can be returned to the consumer from operations in this module.
Variants
Generic(String)
Generic is a generic error for all error types without a more specific type.
DEKNotFound(String)
DEKNotFound is returned from the data encryption key for a capsule cannot be found.
DEKUnexpectedType(String)
DEKUnexpectedType is returned when the library finds a data encryption key with an unknown or unexpected type.
DEKWrongLength(String)
DEKUnexpectedType is returned when the library finds a data encryption key with an unexpected length
CBOREncodeFailed(String)
CBOREncodeFailed is returned when the library fails to encode a value to CBOR.
CBORDecodeFailed(String)
CBOREncodeFailed is returned when the library fails to decode what is expected to be a CBOR-encoded value.
EncryptionFailure(String)
EncryptionFailure is returned when an encryption operation fails.
DecryptionFailure(String)
DecryptionFailure is returned when a decryption operation fails.
BadMagic(String)
BadMagic is returned when the library attempts to read a bundle header but does not find the correct magic value in the header.
UnsupportedVersion(String)
UnsupportedVersion is returned when a capsule bundle header contains an unsupported version.
CapsuleAlreadySealed(String)
CapsuleAlreadySealed is returned when attempting to seal a capsule that is already sealed.
StreamWriteFailure(String)
StreamWriteFailure is returned when the library cannot write to an I/O stream.
StreamReadFailure(String)
StreamWriteFailure is returned when the library cannot read from an I/O stream.
FileIOError(String)
FileIOError is returned when the library encounters an I/O error when attempting to read a capsule bundle.
InsufficientPermissions(String)
InsufficientPermissions is returned when attempting to read a capsule with insufficient permissions.
DRDecryptError(String)
DRDecryptError is returned when attempting to invoke the DR token decoder fails.
CapsuleOpenError(String)
CapsuleOpenError is returned when attempting to open a capsule fails.
CapsuleUpdateError(String)
CapsuleUpdateError is returned when the library encounters an error when attempting to update a capsule.
EndOfRow
EndOfCapsule
CapsuleAccessDeniedByPolicy
RowAccessDeniedByPolicy